<template>
    <div >
        <NoteAdd ref="noteAdd"></NoteAdd>
        <NoteEdit ref="noteEdit"></NoteEdit>
        <NoteView ref="noteView"></NoteView>
        <!-- v-card -->
        <v-card>
            <v-card-title>
                <div>
                    <div class="headline">
                        {{ trans('messages.documents_notes') }}
                    </div>
                </div>
                <v-spacer></v-spacer>
                <v-btn
                    v-if="$can('leadNote.create')"
                    class="primary lighten-1"
                    dark
                    @click="create"
                >
                    {{ trans('messages.add') }}
                    <v-icon right dark>add</v-icon>
                </v-btn>
            </v-card-title>
            <v-divider></v-divider>
            <!-- /v-card -->
            <!-- datatable -->
            <v-data-table
                :headers="headers"
                :options.sync="pagination"
                :server-items-length="total_items"
                :loading="loading"
                :items="items"
                class="elevation-3"
            >
                <template v-slot:item="{ item }">
                    <tr>
                        <td class="text-center">
                            <v-menu>
                                <template v-slot:activator="{on}">
                                    <v-btn icon v-on="on">
                                        <v-icon>more_vert</v-icon>
                                    </v-btn>
                                </template>

                                <v-list>
                                    <v-list-item
                                        v-if="$can('leadNote.view')"
                                        @click="view(item.id)"
                                    >
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> visibility </v-icon>
                                            {{ trans('messages.view') }}
                                        </v-list-item-title>
                                    </v-list-item>

                                    <v-list-item
                                        v-if="$can('leadNote.edit')"
                                        @click="edit(item.id)"
                                    >
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> edit </v-icon>
                                            {{ trans('messages.edit') }}
                                        </v-list-item-title>
                                    </v-list-item>

                                    <v-list-item
                                        v-if="$can('leadNote.delete')"
                                        @click="deleteNote(item)"
                                    >
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> delete_forever </v-icon>
                                            {{ trans('messages.delete') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                </v-list>
                            </v-menu>
                        </td>
                        <td class="text-center">{{ item.heading }}</td>
                        <td class="text-center">{{ item.user.name }}</td>
                        <td class="text-center">{{ item.created_at | formatDateTime }}</td>
                        <td class="text-center">{{ item.updated_at | formatDateTime }}</td>
                    </tr>
                </template>
            </v-data-table>
            <!-- /datatable -->
        </v-card>
    </div>
</template>
<script>
import NoteAdd from './Add';
import NoteEdit from './Edit';
import NoteView from './View';
export default {
    components: {
        NoteAdd,
        NoteEdit,
        NoteView,
    },
    data() {
        const self = this;
        return {
            lead_id: null,
            total_items: 0,
            loading: true,
            pagination: {},
            headers: [
                {
                    text: self.trans('messages.action'),
                    value: false,
                    align: 'center',
                    sortable: false,
                },
                {
                    text: self.trans('messages.heading'),
                    value: 'heading',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.added_by'),
                    value: 'user',
                    align: 'center',
                    sortable: false,
                },
                {
                    text: self.trans('messages.created_at'),
                    value: 'created_at',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.updated_at'),
                    value: 'updated_at',
                    align: 'center',
                    sortable: true,
                },
            ],
            items: [],
        };
    },
    watch: {
        pagination: {
            handler() {
                this.getLeadNotesFromApi();
            },
        },
    },
    mounted() {
        const self = this;
        self.lead_id = self.$route.params.id;
        self.$eventBus.$on('updateLeadNotesTable', data => {
            self.getLeadNotesFromApi();
        });
    },
    beforeDestroy() {
        const self = this;
        self.$eventBus.$off('updateLeadNotesTable');
    },
    methods: {
        getLeadNotesFromApi() {
            const self = this;
            const { sortBy, sortDesc, page, itemsPerPage } = self.pagination;
            axios
                .get('/admin/lead-notes', {
                    params: {
                        sort_by: sortBy,
                        descending: sortDesc,
                        page: page,
                        rowsPerPage: itemsPerPage,
                        lead_id: self.lead_id,
                    },
                })
                .then(function(response) {
                    self.total_items = response.data.total;
                    self.items = response.data.data;
                    self.loading = false;
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        create() {
            var data = { lead_id: this.lead_id };
            this.$refs.noteAdd.create(data);
        },
        view(id) {
            var data = { id: id, lead_id: this.lead_id };
            this.$refs.noteView.view(data);
        },
        edit(id) {
            var data = { id: id, lead_id: this.lead_id };
            this.$refs.noteEdit.edit(data);
        },
        deleteNote(item) {
            const self = this;
            self.$store.commit('showDialog', {
                type: 'confirm',
                icon: 'warning',
                title: self.trans('messages.are_you_sure'),
                message: self.trans('messages.you_cant_restore_it'),
                okCb: () => {
                    axios
                        .delete('/admin/lead-notes/' + item.id, {
                            params: { lead_id: self.lead_id },
                        })
                        .then(function(response) {
                            self.$store.commit('showSnackbar', {
                                message: response.data.msg,
                                color: response.data.success,
                            });

                            if (response.data.success === true) {
                                self.getLeadNotesFromApi();
                            }
                        })
                        .catch(function(error) {
                            console.log(error);
                        });
                },
                cancelCb: () => {
                    console.log('CANCEL');
                },
            });
        },
    },
};
</script>
